@@ -9,7 +9,7 @@ BEGIN {
 }
 use namespace::clean;
 
-our $VERSION= '0.01';
+our $VERSION= '0.011';
 
 # ABSTRACT: Encode elf files with pure-perl
 
@@ -563,7 +563,7 @@ ELF::Writer - Encode elf files with pure-perl
 
 =head1 VERSION
 
-version 0.01
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -678,11 +678,11 @@ the constructor which will be coerced automatically.
 
 =head2 segment_count
 
-Handy alias for C<$#{ $elf->segments }>
+Handy alias for C<< $#{ $elf->segments } >>
 
 =head2 segment_list
 
-Handy alias for C<@{ $elf->segments }>
+Handy alias for C<< @{ $elf->segments } >>
 
 =head2 sections
 
@@ -691,11 +691,11 @@ the constructor which will be coerced automatically.
 
 =head2 section_count
 
-Handy alias for C<$#{ $elf->sections }>
+Handy alias for C<< $#{ $elf->sections } >>
 
 =head2 section_list
 
-Handy alias for C<@{ $elf->sections }>
+Handy alias for C<< @{ $elf->sections } >>
 
 =head2 section_name_string_table_idx
 
@@ -720,9 +720,7 @@ Convenience method for writing to a file.  Writes with mode 0755 by default.
 Brian Raiter has a nice write-up of how to hack around on ELF files, which
 I found very educational:
 
-http://www.muppetlabs.com/~breadbox/software/tiny/teensy.html
-
-=cut
+L<http://www.muppetlabs.com/~breadbox/software/tiny/teensy.html>
 
 =head1 AUTHOR
 
@@ -730,7 +728,7 @@ Michael Conrad <mike@nrdvana.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Michael Conrad.
+This software is copyright (c) 2017 by Michael Conrad.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
